==> qtjambi-xml-5.15.9-sources.jar: io/qt/xml/QDomCharacterData.java <==
package io.qt.xml;


/**
 * <p>Represents a generic string in the DOM</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qdomcharacterdata.html">QDomCharacterData</a></p>
 */
public class QDomCharacterData extends io.qt.xml.QDomNode
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomcharacterdata.html#QDomCharacterData">QDomCharacterData::QDomCharacterData()</a></p>
     */
    public QDomCharacterData(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDomCharacterData instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomcharacterdata.html#QDomCharacterData-1">QDomCharacterData::QDomCharacterData(QDomCharacterData)</a></p>
     */
    public QDomCharacterData(io.qt.xml.QDomCharacterData x){
        super((QPrivateConstructor)null);
        initialize_native(this, x);
    }
    
    private native static void initialize_native(QDomCharacterData instance, io.qt.xml.QDomCharacterData x);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomcharacterdata.html#appendData">QDomCharacterData::appendData(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final void appendData(java.lang.String arg){
        appendData_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), arg);
    }
    
    @io.qt.QtUninvokable
    private native void appendData_native_cref_QString(long __this__nativeId, java.lang.String arg);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomcharacterdata.html#data">QDomCharacterData::data()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String data(){
        return data_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String data_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomcharacterdata.html#deleteData">QDomCharacterData::deleteData(ulong,ulong)</a></p>
     */
    @io.qt.QtUninvokable
    public final void deleteData(int offset, int count){
        deleteData_native_unsigned_long_unsigned_long(QtJambi_LibraryUtilities.internal.nativeId(this), offset, count);
    }
    
    @io.qt.QtUninvokable
    private native void deleteData_native_unsigned_long_unsigned_long(long __this__nativeId, int offset, int count);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomcharacterdata.html#insertData">QDomCharacterData::insertData(ulong,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final void insertData(int offset, java.lang.String arg){
        insertData_native_unsigned_long_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), offset, arg);
    }
    
    @io.qt.QtUninvokable
    private native void insertData_native_unsigned_long_cref_QString(long __this__nativeId, int offset, java.lang.String arg);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomcharacterdata.html#length">QDomCharacterData::length()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int length(){
        return length_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int length_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomcharacterdata.html#replaceData">QDomCharacterData::replaceData(ulong,ulong,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final void replaceData(int offset, int count, java.lang.String arg){
        replaceData_native_unsigned_long_unsigned_long_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), offset, count, arg);
    }
    
    @io.qt.QtUninvokable
    private native void replaceData_native_unsigned_long_unsigned_long_cref_QString(long __this__nativeId, int offset, int count, java.lang.String arg);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomcharacterdata.html#setData">QDomCharacterData::setData(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setData(java.lang.String arg__1){
        setData_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @io.qt.QtUninvokable
    private native void setData_native_cref_QString(long __this__nativeId, java.lang.String arg__1);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomcharacterdata.html#substringData">QDomCharacterData::substringData(ulong,ulong)</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String substringData(int offset, int count){
        return substringData_native_unsigned_long_unsigned_long(QtJambi_LibraryUtilities.internal.nativeId(this), offset, count);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String substringData_native_unsigned_long_unsigned_long(long __this__nativeId, int offset, int count);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QDomCharacterData(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QDomCharacterData clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QDomCharacterData clone_native(long __this_nativeId);
}

==> qtjambi-xml-5.15.10-sources.jar: io/qt/xml/QDomCharacterData.java <==
package io.qt.xml;


/**
 * <p>Represents a generic string in the DOM</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qdomcharacterdata.html">QDomCharacterData</a></p>
 */
public class QDomCharacterData extends io.qt.xml.QDomNode
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomcharacterdata.html#QDomCharacterData">QDomCharacterData::QDomCharacterData()</a></p>
     */
    public QDomCharacterData(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDomCharacterData instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomcharacterdata.html#QDomCharacterData-1">QDomCharacterData::QDomCharacterData(QDomCharacterData)</a></p>
     */
    public QDomCharacterData(io.qt.xml.QDomCharacterData x){
        super((QPrivateConstructor)null);
        initialize_native(this, x);
    }
    
    private native static void initialize_native(QDomCharacterData instance, io.qt.xml.QDomCharacterData x);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomcharacterdata.html#appendData">QDomCharacterData::appendData(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final void appendData(java.lang.String arg){
        appendData_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), arg);
    }
    
    @io.qt.QtUninvokable
    private native void appendData_native_cref_QString(long __this__nativeId, java.lang.String arg);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomcharacterdata.html#data">QDomCharacterData::data()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String data(){
        return data_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String data_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomcharacterdata.html#deleteData">QDomCharacterData::deleteData(ulong,ulong)</a></p>
     */
    @io.qt.QtUninvokable
    public final void deleteData(int offset, int count){
        deleteData_native_unsigned_long_unsigned_long(QtJambi_LibraryUtilities.internal.nativeId(this), offset, count);
    }
    
    @io.qt.QtUninvokable
    private native void deleteData_native_unsigned_long_unsigned_long(long __this__nativeId, int offset, int count);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomcharacterdata.html#insertData">QDomCharacterData::insertData(ulong,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final void insertData(int offset, java.lang.String arg){
        insertData_native_unsigned_long_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), offset, arg);
    }
    
    @io.qt.QtUninvokable
    private native void insertData_native_unsigned_long_cref_QString(long __this__nativeId, int offset, java.lang.String arg);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomcharacterdata.html#length">QDomCharacterData::length()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int length(){
        return length_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int length_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomcharacterdata.html#replaceData">QDomCharacterData::replaceData(ulong,ulong,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final void replaceData(int offset, int count, java.lang.String arg){
        replaceData_native_unsigned_long_unsigned_long_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), offset, count, arg);
    }
    
    @io.qt.QtUninvokable
    private native void replaceData_native_unsigned_long_unsigned_long_cref_QString(long __this__nativeId, int offset, int count, java.lang.String arg);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomcharacterdata.html#setData">QDomCharacterData::setData(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setData(java.lang.String arg__1){
        setData_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @io.qt.QtUninvokable
    private native void setData_native_cref_QString(long __this__nativeId, java.lang.String arg__1);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomcharacterdata.html#substringData">QDomCharacterData::substringData(ulong,ulong)</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String substringData(int offset, int count){
        return substringData_native_unsigned_long_unsigned_long(QtJambi_LibraryUtilities.internal.nativeId(this), offset, count);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String substringData_native_unsigned_long_unsigned_long(long __this__nativeId, int offset, int count);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QDomCharacterData(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QDomCharacterData clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QDomCharacterData clone_native(long __this_nativeId);
}
